@@ -5,6 +5,7 @@ use CGI::Application;
 use HTTP::Status ':constants';
 use Mojo::Util 'dumper';
 use Sentry::SDK;
+use Sys::Hostname 'hostname';
 
 my $_initialized;
 
@@ -17,6 +18,10 @@ CGI::Application->add_callback(
     my $options = $c->param('sentry_options');
     Sentry::SDK->init($options);
 
+    Sentry::SDK->configure_scope(sub ($scope) {
+      $scope->set_tags({ runtime => "Perl $]", server_name => hostname });
+    });
+
     $_initialized = 1;
   }
 );
@@ -33,6 +38,7 @@ CGI::Application->add_callback(
       $scope->set_tags({
         runtime => "Perl $]",
         url     => $c->query->url(-full => 1, -path => 1, -query => 1),
+        runmode => $rm,
       });
     });
 
